#!/bin/sh

#
# TeamFile Server Install Script
#

TEAMFILEREPO="/etc/yum.repos.d/TeamFile.repo"
USER=user
PASS=teamfile

MT_FUNCTION_HOME=/usr/local/teamfile/www/bin

setup_reposdb() {

	MT_FUNCTION="${MT_FUNCTION_HOME}/mt-lib"
	. ${MT_FUNCTION}

	PGDATA="/var/lib/tfpgsql/PGDATA"
	rm -fr ${PGDATA}
	mkdir -p ${PGDATA}

	chown ${PG_ADMIN_USER}:${PG_ADMIN_GROUP} "${PGDATA}"
	su - ${PG_ADMIN_USER} -c "${PG_HOME}/bin/initdb --encoding=UNICODE --no-locale -D ${PGDATA}"

	# copy sample configuration
	sample_base="/var/lib/tfpgsql/samples"
	if test -d ${sample_base} && test -f ${sample_base}/pg_hba.conf.sample; then
		cp -p ${sample_base}/pg_hba.conf.sample ${PGDATA}/pg_hba.conf
	fi

	if test -d ${sample_base} && test -f ${sample_base}/postgresql.conf.sample; then
		cp -p ${sample_base}/postgresql.conf.sample ${PGDATA}/postgresql.conf
	fi

	# check memory
	memtotal=`cat /proc/meminfo | grep MemTotal | sed -e 's/MemTotal:[ ]*//g' -e 's/[ ]kB//'`
	if [ $memtotal -lt 2058708 ]; then
		memtotal=`expr ${memtotal} \* 20 / 100 / 1000`
		sed -i.org -e "s/^\(shared_buffers.*\)/#\1\nshared_buffers = ${memtotal}kB/g" ${PGDATA}/postgresql.conf
	fi


	/etc/init.d/tfpostgres start
	echo "wait 5 min ..." && sleep 5

	echo -n "* create new database user ... "
	TF_DB_HOST_NAME="localhost"
	TF_DB_PORT_NO="5432"
	TF_DB_USER_NAME="tfdbuser"
	${PG_HOME}/bin/createuser -D -A -h ${TF_DB_HOST_NAME} -p ${TF_DB_PORT_NO} -U ${PG_ADMIN_USER} ${TF_DB_USER_NAME}
	echo " done."

}

#download rpmforge 
rpm -ivh http://pkgs.repoforge.org/rpmforge-release/rpmforge-release-0.5.3-1.el6.rf.x86_64.rpm

# setup teamfile yum repository 
cat << _END_ > ${TEAMFILEREPO}
[teamfile]
name=TeamFile-\$releaseserver
baseurl=https://${USER}:${PASS}@dl.teamfile.com/dev/server/RHEL\$releasever/\$basearch/current
enable=0
gpgcheck=0
_END_

# yum install
yum install -y --enablerepo=teamfile pk-mod_dav_tf-pg9 pk-postgresql pk-postgresql-server pk-postgresql-contrib pk-libapreq2 pk-cmd pk-tfsplugin pk-apr-util-ldap rsync

# install LITE license [1 user]
curl -fsS -u ${USER}:${PASS} https://dl.teamfile.com/server/config/tf_license.conf -o /usr/local/teamfile/www/conf/conf.d/tf_license.conf

# startup teamfile memcached
/etc/init.d/tfmemcached start

# setup and startup postgresql
setup_reposdb

# remove storage path
rm -fr /var/lib/teamfile/STORAGE

# setup teamfile location
INIFILE="/usr/local/teamfile/www/conf/conf.d/newlocation.ini"
cat /usr/local/teamfile/www/conf/conf.d/newlocation_template.default | sed -e 's/^\(TF_ROOT_URI\).*/\1="teamfile"/' >${INIFILE} 

if [ -f ${INIFILE} ]; then
	${MT_FUNCTION_HOME}/maintenance.sh -o newlocation -f ${INIFILE} -s
fi

# start up teamfile
/etc/init.d/teamfile start

# stop iptables
/etc/init.d/iptables stop

# setup crontab
cat << _END_ > /var/spool/cron/root
# min hour day month week command
#-------------------------------------------------------------------------
#00   05   *    *    *    (/bin/sh /usr/local/teamfile/www/bin/dailybat.sh ; /bin /sh /usr/local/teamfile/www/bin/tfupdater -I -s)
*    *    *    *    *    /usr/local/teamfile/www/bin/tfscheduler
_END_
chmod 600 /var/spool/cron/root

# cleanup
rm -fr ${TEAMFILEREPO}

exit 0

