//------------------------------------------------------------------------------
// $Id: tfscommon.js 4116 2015-10-29 07:16:03Z yone $
// JavaScript common functions
// Copyright (c) 2006,2007 COMPUTER HI-TECH INC., All rights reserved.
//------------------------------------------------------------------------------

// Define global constant

var gUa = navigator.userAgent.toLowerCase();

// for OS
var gWin = (gUa.indexOf("windows") != -1);

// for Browser
var gMsie5mac = (gUa.indexOf("msie 5") != -1 && gUa.indexOf("mac_powerpc") != -1);
var gMsie     = ((gUa.indexOf("msie") != -1) && (gUa.indexOf("opera") == -1) && (gUa.indexOf("windows") != -1));
var gGecko    = (gUa.indexOf("gecko") != -1);
var gOpera    = (gUa.indexOf("opera") != -1);

var gHost = location.protocol + "//" + location.host;
// -----------------------------------------------------------------------------
// Check single byte character for SJIS
//
// @param c0 int previous character code. (0x00 -> ignore)
// @param c  int target charcter code.
// @return true / false
// -----------------------------------------------------------------------------
function isSjisSingleByte(c0, c)
{
	if ((c >= 0x00 && c <= 0x1F) || c == 0x7F) {
		return true;
	}
	else if (c >= 0x20 && c <= 0x3F) {
		return true;
	}
	else if (c >= 0x40 && c <= 0x7E) {
		if (!((c0 >= 0x81 && c0 <= 0x9F) || (c0 >= 0xE0 && c0 <= 0xFC))) {
			return true;
		}
	}
	else if (c >= 0xA1 && c <= 0xDF) {
		if (!((c0 >= 0x81 && c0 <= 0x9F) || (c0 >= 0xE0 && c0 <= 0xFC))) {
			return true;
		}
	}

	return false;
}

// -----------------------------------------------------------------------------
// Extract final path segment from path string.
//
// @param path String path-string
// @return String
// -----------------------------------------------------------------------------
function extractFileName(path)
{
	var fname;

	if (path == null || path == "") {
		return "";
	}

	if (gWin) {
		fname = path.split("\\");
		if (fname.legnth == 0) {
			return fname[0];
		}
		else {
			return fname[fname.length - 1];
		}
	}
	else {
		fname = path.split("/");
		if (fname.legnth == 0) {
			return fname[0];
		}
		else {
			return fname[fname.length - 1];
		}
	}
}

// -----------------------------------------------------------------------------
// get Parent URI from uri string.
//
// @param path String path-string 
// @return String
// -----------------------------------------------------------------------------
function getParentURI(path)
{
	var pos = path.lastIndexOf("/");

	if (pos>0) {
		return path.substring(0, pos+1);
	}

	return path;

}
// -----------------------------------------------------------------------------
// Check including KINSOKU character (see getKinsokuString())
//
// @param name String
// @return true: include KINSOKU  / false : NOT include KINSOKU
// -----------------------------------------------------------------------------
function isKinsokuName(name)
{
	var i, ch, len, c0, c;
	if (name == null || name == "") {
		return false;
	}

	c0 = 0x00;
	for (i = 0; i < name.length; i++) {
		ch = name.charAt(i);
		if (gMsie5mac) {
			if (i > 0) {
				c0 = name.charAt(i-1);
			}
			c  = ch.charCodeAt(0);

			if (!isSjisSingleByte(c0, c)) {
				i++;
				continue;
			}
		}

		if (ch == "\\" || (gWin && ch == "/") || (gWin && ch == ":") || (gWin && ch == "*") ||
			ch == "?"  || ch == "\"" || ch == "<" || ch == ">" || ch == "|") {
			return true;
		}
	}

	return false;
}

// -----------------------------------------------------------------------------
// Get KINSOKU string
//
// @return string
// -----------------------------------------------------------------------------
var gKinsokuStr = '\\ / : * ? " < > |';

function getKinsokuString()
{
	return gKinsokuStr;
}

// -----------------------------------------------------------------------------
// Get UTC To LocalTime
//
// @param  UTC string (Format ISO 8601 only)
// @return Date Object
// -----------------------------------------------------------------------------
function convertUTCtoLocal(utcstr)
{
	var d;
	var epoch = 0;
	var offset = 0;

	if (utcstr == null || utcstr == "") return null;

	// local offset
	offset =  new Date().getTimezoneOffset() * (60 * 1000);

	// ISO8601 format
	d = utcstr.match(/(\d+)-(\d+)-(\d+)T(\d+):(\d+):(\d+)Z/);
	if (d == null) { return null; }

	// UTC epoch
	epoch = new Date(d[1], d[2]-1, d[3], d[4], d[5], d[6]).getTime();

	var local = new Date();
	local.setTime(epoch - offset);

	return local;
}

// -----------------------------------------------------------------------------
// Local To UTC object
//
// @param  localdate ( format: yyyy/mm/dd )
// @param  localtime ( format: HH/MM/SS )
//
// @return Date Object
// -----------------------------------------------------------------------------
function convertLocalToUTC(localtime)  
{
	var d;
	var utc = new Date();
	var epoch;

	// japanease style
	d = localtime.match(/(\d+)\/(\d+)\/(\d+) (\d+):(\d+):(\d+)/);
	if (d == null) { return null; }

	epoch = new Date(d[1], d[2]-1, d[3], d[4], d[5], d[6]).getTime() + (utc.getTimezoneOffset()*60*1000);
	
	utc.setTime(epoch);

	return utc;
}

// -----------------------------------------------------------------------------
// Change TR color, Recover TR color
// 
// -----------------------------------------------------------------------------
var _gOrigColors;
function onFocusLine(obj)
{
	if (obj) {
		var tdNodeList = obj.getElementsByTagName('td');
		if (typeof(tdNodeList) != 'undefined' && tdNodeList) {
			_gOrigColors = new Array();
			for (var i = 0; i < tdNodeList.length; i++) {
				_gOrigColors[i] = tdNodeList[i].style.backgroundColor;
				tdNodeList[i].style.backgroundColor = "#d4ecff";
			}
		}
		
		var spanList = obj.getElementsByTagName('span');
		if (typeof(spanList) != 'undefined' && spanList && spanList.length != 0) {
			for (var i = 0; i < spanList.length; i++) {
				spanList[i].style.visibility = "visible";
			}
		}

	}
	return true;
}

function onBlurLine(obj)
{
	if (obj) {
		var tdNodeList = obj.getElementsByTagName('td');
		if (typeof(tdNodeList) != 'undefined' && tdNodeList) {
			for (var i = 0; i < tdNodeList.length; i++) {
				if (_gOrigColors) {
					tdNodeList[i].style.backgroundColor = _gOrigColors[i];
				}
				else {
					tdNodeList[i].style.backgroundColor = "#f5f5ff";
				}
			}
			_gOrigColors = null;
		}

		var spanList = obj.getElementsByTagName('span');
		if (typeof(spanList) != 'undefined' && spanList && spanList.length != 0) {
			for (var i = 0; i < spanList.length; i++) {
				spanList[i].style.visibility = "hidden";
			}
		}
	}
	return true;
}

function inFolder(id) 
{
	location.href = document.getElementById(id).href;
}

//
//
//
Date.prototype.tfformat = function(format) {
	var me = this;
	var t = {
		Y:function() { return me.getFullYear() } ,
		m:function() { return ('0' + (me.getMonth()+1)).slice(-2)},
		d:function() { return ('0' + me.getDate()).slice(-2)   },
		H:function() { return ('0' + me.getHours()).slice(-2)  },
		i:function() { return ('0' + me.getMinutes()).slice(-2)},
		s:function() { return ('0' + me.getSeconds()).slice(-2)}
	};

	return format.replace(/[YmdHis]/g, function(l) { return t[l].apply(me); });

}

Date.prototype.tfformatISO8601 = function() {

}


// -----------------------------------------------------------------------------
// calendar UI
//
// @param parent Element
// @return void
// -----------------------------------------------------------------------------
function TfCalendar(parent) {
	this.parent = document.getElementById(parent);
};

TfCalendar.prototype = {
	create: function(year, month, lang) {
		var me = this;
		me.lang = lang || 'ja';

		var table = document.createElement('table');
		table.className = 'tfcalendar';
		me.table = table;
		table.onclick = function(e) {
			var evt = e || window.event;
			var target = evt.target || evt.srcElement;
			if (target.tagName === 'A') {
				if (target.hash.indexOf('#tfcal-m-') === 0) {
					return me.update.apply(me, target.hash.match(/tfcal-m-(\d+)-(\d+)/));
				}
				else if (target.hash.indexOf('#tfcal-d-') === 0) {
					return me.onclickdate.apply(me, target.hash.match(/tfcal-d-(\d+)-(\d+)-(\d+)/));
				}
				else if (target.hash.indexOf('#tfcal-today-') === 0) {
					return me.update.apply(me, target.hash.match(/tfcal-today-(\d+)-(\d+)-(\d+)/));
				}
			}
			if (target.tagName === 'IMG') {
				me.hide();
			}
		}
		me.setDate(year, month);
		me.setCaption(me.year, me.month);
		me.setBody(me.year, me.month, me.lang);
		me.setFooter();
		this.parent.appendChild(me.table);

		return me;
	},
	hide: function() {
		this.parent.style.display = 'none';
	},
	remove: function() {
		this.parent.removeChild(this.table);
	},
	update: function(id, year, month) {
		this.remove();
		this.create(year, month);
		return false;
	},
	onclickdate: function(id, year, month, date) {
		return false;
	},
	setCaption: function(year, month) {
		var me = this;
		var caption = document.createElement('caption');
		var div   = document.createElement('div');
		var next  = document.createElement('a');
		var prev  = document.createElement('a');
		var close = document.createElement('img');

		close.src = '/icons/teamfile/tf_close.png';
		next.href = '#tfcal-m-' + ((month === 12) ? year+1 : year) + '-' + (month===12?1:month+1);
		prev.href = '#tfcal-m-' + ((month === 1) ? year-1 : year) + '-' + (month===1?12:month-1);
		next.innerHTML = '&rarr;';
		next.className = 'next';
		prev.innerHTML = '&larr;';
		prev.className = 'prev';

		var current = document.createElement('span');
		var text = document.createTextNode((me.lang == 'ja')?year + '/' + month:month + '/' + year);
		current.appendChild(text);
		div.appendChild(prev);
		div.appendChild(current);
		div.appendChild(close);
		div.appendChild(next);
		caption.appendChild(div);
		me.table.appendChild(caption);
	},
	setDate: function(year, month) {
		var me    = this;
		var today = new Date();
		me.year = parseInt(year,  10) || today.getFullYear();
		me.month= parseInt(month, 10) || today.getMonth()+1;
	},
	setBody: function(year, month) {
		var me    = this;
		var tbody = document.createElement('tbody');
		var first = new Date(year, month - 1, 1);
		var last  = new Date(year, month, 0);
		var first_day = first.getDay();
		var last_date = last.getDate();
		var today = new Date();
		var today_year  = today.getFullYear();
		var today_month = today.getMonth()+1;
		var today_date  = today.getDate();
		var date  = 1;
		var skip  = true;

		for (var row=0; row<7; row++) {
			var tr = document.createElement('tr');
			for (var col=0;col<7; col++) {
				if (row === 0) {
					var th = document.createElement('th');
					var day_ja = ['日', '月', '火', '水', '木', '金', '土'];
					var day_en = ['SUN', 'MON', 'TUE', 'WED', 'THR', 'FRI', 'SAT'];
					var day = eval("day_" + me.lang + "[col]");
					th.appendChild(document.createTextNode(day));
					th.className = 'header-day' + col;
					tr.appendChild(th);
				}
				else {
					if (row === 1 && first_day === col) { skip = false; }
					if (date > last_date) { skip = true; }

					var td = document.createElement('td');
					td.className = 'tfcal-day' + col;
					if (!skip) {
						var a = document.createElement('a');
						a.href = '#tfcal-d-' + year + '-' + month + '-' + date;
						a.appendChild(document.createTextNode(date));

						if (year === today_year && month === today_month && date === today_date) {
							a.className = 'tfcal-today';
						}
						td.appendChild(a);
						date++;
					}
					else {
						td.innerHTML='<span>&nbsp;</span>';
					}
					tr.appendChild(td);
				}
				tbody.appendChild(tr);
			}
		}
		me.table.appendChild(tbody);
	},
	setFooter: function() {
		var me    = this;
		var today = new Date();
		var tr    = document.createElement('tr');
		var td    = document.createElement('td');
		var div   = document.createElement('div');
		var a     = document.createElement('a');
		a.href    = "#tfcal-today-" + today.getFullYear() + '-' + parseInt(today.getMonth()+1) + '-' + today.getDate();
		a.appendChild(document.createTextNode((me.lang=='ja')?'本日':'Today'));
		div.appendChild(a);
		td.colSpan = 7;
		td.appendChild(div);
		tr.appendChild(td);
		me.table.appendChild(tr);
	}
};

// -----------------------------------------------------------------------------
// GUID Generator
//
//
// -----------------------------------------------------------------------------
function guid() {
	var s4 = function() {
		return (((1+Math.random())*0x10000)|0).toString(16).substring(1);
	}
	return (s4()+s4()+"-"+s4()+"-"+s4()+"-"+s4()+"-"+s4()+s4()+s4());
}

// -----------------------------------------------------------------------------
// -----------------------------------------------------------------------------
RegExp.quote = function(str) {
	return (str+'').replace(/([.?*+^$[\]\\(){}|-])/g, "\\$1");
}

function DragStart(event) 
{
	event.dataTransfer.setData("text", event.target.id);
}

